empty

Function empty 

pub fn empty() -> Empty
👎Deprecated since 0.2.0:

Use Empty::new() instead

An empty View. This view can still have a size, background, border radius, and outline.

This view can be used as a simple placeholder view when another view requires a child element but there is no meaningful child element to be provided.