pub struct Button { /* private fields */ }Expand description
A simple Button view. See button.
Implementations
Sourceimpl Button
impl Button
Sourcepub fn new(child: impl IntoView) -> Self
pub fn new(child: impl IntoView) -> Self
Creates a new Button with the given child view.
Examples
// Basic usage
let button1 = Button::new("Click me").action(move || println!("Button1 clicked!"));
let button2 = Button::new("Click me").action(move || println!("Button2 clicked!"));
// Apply styles for the button
let styled = Button::new("Click me")
.action(|| println!("Styled button clicked!"))
.style(|s| s
.border(1.0)
.border_radius(10.0)
.padding(10.0)
.background(css::YELLOW_GREEN)
.color(css::DARK_GREEN)
.cursor(CursorStyle::Pointer)
.active(|s| s.color(css::WHITE).background(css::RED))
.hover(|s| s.background(Color::from_rgb8(244, 67, 54)))
.focus_visible(|s| s.border(2.).border_color(css::BLUE))
);Reactivity
Button’s label is not reactive. For reactive content, pass a reactive view as the child.