pub struct Empty { /* private fields */ }Expand description
An empty View.
This view can still have a size, background, border radius, and outline. It can be used as a simple placeholder view when another view requires a child element but there is no meaningful child element to be provided.
Implementations