Empty

Struct Empty 

pub struct Empty { /* private fields */ }
An empty View.

This view can still have a size, background, border radius, and outline. It can be used as a simple placeholder view when another view requires a child element but there is no meaningful child element to be provided.

Implementations

Source

impl Empty

pub fn new() -> Self

Creates a new empty view.

Example
use floem::views::Empty;

let placeholder = Empty::new();
pub fn with_id(id: ViewId) -> Self

Creates a new empty view with a pre-existing ViewId.

This is useful for lazy view construction where the ViewId is created before the view itself.