pub struct ToggleButton { /* private fields */ }Expand description
A toggle button.
Implementations
Sourceimpl ToggleButton
impl ToggleButton
Sourcepub fn new(state: impl Fn() -> bool + 'static) -> Self
pub fn new(state: impl Fn() -> bool + 'static) -> Self
Create new ToggleButton.
When the button is toggled by clicking or dragging the widget, an update will be
sent to the ToggleButton::on_toggle handler.
By default this toggle button has a style class of ToggleButtonClass applied
with a default style provided.
Examples
// An example using read-write signal
let state = RwSignal::new(true);
let toggle = toggle_button(move || state.get())
.on_toggle(move |new_state| state.set(new_state));Reactivity
This function is reactive and will reactively respond to changes.
Sourcepub fn new_rw(
state: impl SignalGet<bool> + SignalUpdate<bool> + Copy + 'static,
) -> Self
pub fn new_rw( state: impl SignalGet<bool> + SignalUpdate<bool> + Copy + 'static, ) -> Self
Create new ToggleButton with read-write signal.
Examples
// Create read-write signal that will hold toggle button state
let state = RwSignal::new(false);
let simple = ToggleButton::new_rw(state);Reactivity
This function will update provided signal on toggle or will be updated if signal changes due to external signal update.
Sourcepub fn on_toggle(self, ontoggle: impl Fn(bool) + 'static) -> Self
👎Deprecated: use .on_event_stop(ToggleChanged::listener(), |_, _|) directly instead
pub fn on_toggle(self, ontoggle: impl Fn(bool) + 'static) -> Self
Add an event handler to be run when the button is toggled.
This does not run if the state is changed because of an outside signal.
Sourcepub fn toggle_style(
self,
style: impl Fn(ToggleButtonCustomStyle) -> ToggleButtonCustomStyle + 'static,
) -> Self
pub fn toggle_style( self, style: impl Fn(ToggleButtonCustomStyle) -> ToggleButtonCustomStyle + 'static, ) -> Self
Set styles related to ToggleButton:
- handle color
- accent color
- handle inset
- circle radius